#[repr(u8)]pub enum AppId {
Sui = 0,
Narwhal = 1,
Consensus = 2,
}Expand description
This enums specifies the application ID. Two intents in two different applications (i.e., Narwhal, Sui, Ethereum etc) should never collide, so that even when a signing key is reused, nobody can take a signature designated for app_1 and present it as a valid signature for an (any) intent in app_2.
Variants