#[repr(u8)]pub enum IntentScope {
TransactionData = 0,
TransactionEffects = 1,
CheckpointSummary = 2,
PersonalMessage = 3,
SenderSignedTransaction = 4,
ProofOfPossession = 5,
HeaderDigest = 6,
BridgeEventUnused = 7,
ConsensusBlock = 8,
}Expand description
This enums specifies the intent scope. Two intents for different scope should never collide, so no signature provided for one intent scope can be used for another, even when the serialized data itself may be the same.
Variants
TransactionData = 0
TransactionEffects = 1
CheckpointSummary = 2
PersonalMessage = 3
SenderSignedTransaction = 4
ProofOfPossession = 5
HeaderDigest = 6
BridgeEventUnused = 7
ConsensusBlock = 8