#[repr(u8)]pub enum IntentVersion {
V0 = 0,
}Expand description
The version here is to distinguish between signing different versions of the struct or enum. Serialized output between two different versions of the same struct/enum might accidentally (or maliciously on purpose) match.
Variants
V0 = 0