pub struct Intent {
pub scope: IntentScope,
pub version: IntentVersion,
pub app_id: AppId,
}Expand description
An intent is a compact struct serves as the domain separator for a message that a signature commits to. It consists of three parts: [enum IntentScope] (what the type of the message is), [enum IntentVersion], [enum AppId] (what application that the signature refers to). It is used to construct [struct IntentMessage] that what a signature commits to.
The serialization of an Intent is a 3-byte array where each field is represented by a byte.
Fields
scope: IntentScopeversion: IntentVersionapp_id: AppIdImplementations
Sourceimpl Intent
impl Intent
pub const fn sui_app(scope: IntentScope) -> Self
pub const fn sui_transaction() -> Self
pub const fn personal_message() -> Self
pub const fn narwhal_app(scope: IntentScope) -> Self
pub const fn consensus_app(scope: IntentScope) -> Self