pub struct IntentMessage<T> {
pub intent: Intent,
pub value: T,
}Expand description
Intent Message is a wrapper around a message with its intent. The message can be any type that implements [trait Serialize]. ALL signatures in Sui must commits to the intent message, not the message itself. This guarantees any intent message signed in the system cannot collide with another since they are domain separated by intent.
The serialization of an IntentMessage is compact: it only appends three bytes to the message itself.
Fields
intent: Intentvalue: TImplementations