pub struct Keystore { /* private fields */ }Implementations
Sourceimpl Keystore
impl Keystore
Sourcepub fn new_default() -> Result<Self, Error>
pub fn new_default() -> Result<Self, Error>
Loads a keystore from the default path: $HOME/.sui/sui_config/sui.keystore.
pub fn new(path: PathBuf) -> Result<Self, Error>
pub fn path(&self) -> &Path
pub const fn aliases(&self) -> &BTreeMap<Address, Alias>
pub fn get_public_key(&self, address: Address) -> Option<PublicKey>
pub fn sign_message( &self, message: &[u8], signer: Address, ) -> Result<SimpleSignature, Error>
Sourcepub fn sign_tx(
&self,
transaction: &Transaction,
signer: Address,
) -> Result<SimpleSignature, Error>
pub fn sign_tx( &self, transaction: &Transaction, signer: Address, ) -> Result<SimpleSignature, Error>
Sign the transaction for a simple address. Fails if the keystore lacks the private
key for it.
Sourcepub fn multisign_tx(
&self,
transaction: &Transaction,
committee: MultisigCommittee,
indices: &[usize],
) -> Result<MultisigAggregatedSignature, Error>
pub fn multisign_tx( &self, transaction: &Transaction, committee: MultisigCommittee, indices: &[usize], ) -> Result<MultisigAggregatedSignature, Error>
Sign the transaction for a native Sui multisig address. Fails if the keystore lacks the
private keys for the signers with the given indices.