pub struct MultiSig { /* private fields */ }Expand description
The struct that contains signatures and public keys necessary for authenticating a MultiSig.
Implementations
Sourceimpl MultiSig
impl MultiSig
Sourcepub fn combine(
full_sigs: Vec<Signature>,
multisig_pk: MultiSigPublicKey,
) -> Result<Self, Error>
pub fn combine( full_sigs: Vec<Signature>, multisig_pk: MultiSigPublicKey, ) -> Result<Self, Error>
This combines a list of [enum Signature] flag || signature || pk to a MultiSig.
The order of full_sigs must be the same as the order of public keys in
[enum MultiSigPublicKey]. e.g. for [pk1, pk2, pk3, pk4, pk5],
[sig1, sig2, sig5] is valid, but [sig2, sig1, sig5] is invalid.
pub fn init_and_validate(&self) -> Result<Self, FastCryptoError>
pub const fn get_pk(&self) -> &MultiSigPublicKey
pub fn get_sigs(&self) -> &[CompressedSignature]
pub fn get_indices(&self) -> Result<Vec<u8>, Error>